# Python personal set of utils

My set of custom utils that I'm going to use in my projects

## Package name in PyPi is ytils

[ytils2](https://test.pypi.org/project/ytils2/#description)


```bash
pip install -i https://test.pypi.org/simple/ ytils2 --upgrade
```
